import { ServiceProto } from 'tsrpc-proto';
import { ReqRoomJoin, ResRoomJoin } from './room/PtlRoomJoin';
import { MsgAck } from './room/client/MsgAck';

export interface ServiceType {
    api: {
        "RoomJoin": {
            req: ReqRoomJoin,
            res: ResRoomJoin
        }
    },
    msg: {
        "msg/client/Ack": MsgAck,
    }
}

export const serviceProto: ServiceProto<ServiceType> = {
    "version": 36,
    "services": [
        {
            "id": 25,
            "name": "msg/client/Ack",
            "type": "msg"
        },
        {
            "id": 13,
            "name": "msg/client/GameAction",
            "type": "msg"
        },
        {
            "id": 18,
            "name": "msg/client/SyncMap",
            "type": "msg"
        },
        {
            "id": 24,
            "name": "msg/server/ActionAck",
            "type": "msg"
        },
        {
            "id": 14,
            "name": "msg/server/GameAction",
            "type": "msg"
        },
        {
            "id": 19,
            "name": "msg/server/NotifySync",
            "type": "msg"
        },
        {
            "id": 15,
            "name": "msg/server/PlayerJoin",
            "type": "msg"
        },
        {
            "id": 16,
            "name": "msg/server/PlayerLeave",
            "type": "msg"
        },
        {
            "id": 22,
            "name": "msg/server/PlayerStateChange",
            "type": "msg"
        },
        {
            "id": 23,
            "name": "msg/server/SyncMapServer",
            "type": "msg"
        },
        {
            "id": 26,
            "name": "GetMsg",
            "type": "api"
        },
        {
            "id": 5,
            "name": "RoomJoin",
            "type": "api"
        },
        {
            "id": 6,
            "name": "RoomLeave",
            "type": "api"
        },
        {
            "id": 11,
            "name": "TestMatch",
            "type": "api",
            "conf": {
                "needLogin": true
            }
        }
    ],
    "types": {
        "msg/client/MsgAck/MsgAck": {
            "type": "Interface",
            "properties": [
                {
                    "id": 0,
                    "name": "sns",
                    "type": {
                        "type": "Array",
                        "elementType": {
                            "type": "Number"
                        }
                    }
                }
            ]
        },
        "msg/client/MsgGameAction/MsgGameAction": {
            "type": "Reference",
            "target": "../../shared/types/GameAction/GameAction"
        },
        "../../shared/types/GameAction/GameAction": {
            "type": "Interface",
            "properties": [
                {
                    "id": 0,
                    "name": "type",
                    "type": {
                        "type": "Literal",
                        "literal": "GameAction"
                    }
                },
                {
                    "id": 1,
                    "name": "playerId",
                    "type": {
                        "type": "String"
                    },
                    "optional": true
                },
                {
                    "id": 2,
                    "name": "actionName",
                    "type": {
                        "type": "String"
                    }
                },
                {
                    "id": 3,
                    "name": "data",
                    "type": {
                        "type": "Any"
                    }
                },
                {
                    "id": 4,
                    "name": "creatorQueue",
                    "type": {
                        "type": "Array",
                        "elementType": {
                            "type": "Interface",
                            "properties": [
                                {
                                    "id": 0,
                                    "name": "key",
                                    "type": {
                                        "type": "String"
                                    }
                                },
                                {
                                    "id": 1,
                                    "name": "ids",
                                    "type": {
                                        "type": "Array",
                                        "elementType": {
                                            "type": "String"
                                        }
                                    }
                                }
                            ]
                        }
                    },
                    "optional": true
                },
                {
                    "id": 6,
                    "name": "time",
                    "type": {
                        "type": "Number"
                    },
                    "optional": true
                },
                {
                    "id": 5,
                    "name": "sendTag",
                    "type": {
                        "type": "Number"
                    },
                    "optional": true
                }
            ]
        },
        "msg/client/MsgSyncMap/MsgSyncMap": {
            "type": "Interface",
            "properties": [
                {
                    "id": 17,
                    "name": "data",
                    "type": {
                        "type": "Any"
                    }
                }
            ]
        },
        "msg/server/MsgActionAck/MsgActionAck": {
            "type": "Interface",
            "properties": [
                {
                    "id": 1,
                    "name": "sendTag",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 2,
                    "name": "players",
                    "type": {
                        "type": "Any"
                    }
                }
            ]
        },
        "msg/server/MsgGameAction/MsgGameAction": {
            "type": "Interface",
            "properties": [
                {
                    "id": 0,
                    "name": "state",
                    "type": {
                        "type": "Any"
                    }
                },
                {
                    "id": 2,
                    "name": "players",
                    "type": {
                        "type": "Any"
                    }
                },
                {
                    "id": 1,
                    "name": "sn",
                    "type": {
                        "type": "Number"
                    }
                }
            ]
        },
        "msg/server/MsgNotifySync/MsgNotifySync": {
            "type": "Interface",
            "properties": [
                {
                    "id": 0,
                    "name": "playerId",
                    "type": {
                        "type": "String"
                    }
                }
            ]
        },
        "msg/server/MsgPlayerJoin/MsgPlayerJoin": {
            "type": "Interface",
            "properties": [
                {
                    "id": 0,
                    "name": "player",
                    "type": {
                        "type": "Reference",
                        "target": "../../shared/game/state/PlayerState/PlayerState"
                    }
                },
                {
                    "id": 1,
                    "name": "time",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 2,
                    "name": "mapData",
                    "type": {
                        "type": "String"
                    },
                    "optional": true
                }
            ]
        },
        "../../shared/game/state/PlayerState/PlayerState": {
            "type": "Interface",
            "properties": [
                {
                    "id": 0,
                    "name": "id",
                    "type": {
                        "type": "String"
                    }
                },
                {
                    "id": 1,
                    "name": "seatId",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 2,
                    "name": "score",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 3,
                    "name": "pre_score",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 4,
                    "name": "power",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 5,
                    "name": "avatar",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 6,
                    "name": "avatarFrame",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 7,
                    "name": "nickName",
                    "type": {
                        "type": "String"
                    }
                },
                {
                    "id": 8,
                    "name": "cardId",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 9,
                    "name": "ready",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 10,
                    "name": "useProps",
                    "type": {
                        "type": "Array",
                        "elementType": {
                            "type": "Number"
                        }
                    }
                },
                {
                    "id": 11,
                    "name": "cup",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 12,
                    "name": "online",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 13,
                    "name": "robotId",
                    "type": {
                        "type": "String"
                    },
                    "optional": true
                },
                {
                    "id": 15,
                    "name": "pre_cubes",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 16,
                    "name": "step",
                    "type": {
                        "type": "Number"
                    },
                    "optional": true
                },
                {
                    "id": 17,
                    "name": "vip",
                    "type": {
                        "type": "Number"
                    },
                    "optional": true
                },
                {
                    "id": 18,
                    "name": "data",
                    "type": {
                        "type": "Any"
                    },
                    "optional": true
                }
            ]
        },
        "msg/server/MsgPlayerLeave/MsgPlayerLeave": {
            "type": "Interface",
            "properties": [
                {
                    "id": 0,
                    "name": "playerId",
                    "type": {
                        "type": "String"
                    }
                }
            ]
        },
        "msg/server/MsgPlayerStateChange/MsgPlayerStateChange": {
            "type": "Interface",
            "properties": [
                {
                    "id": 0,
                    "name": "playerId",
                    "type": {
                        "type": "String"
                    }
                },
                {
                    "id": 1,
                    "name": "state",
                    "type": {
                        "type": "Reference",
                        "target": "../../shared/game/state/OnlineState/OnlineState"
                    }
                }
            ]
        },
        "../../shared/game/state/OnlineState/OnlineState": {
            "type": "Enum",
            "members": [
                {
                    "id": 0,
                    "value": 1
                },
                {
                    "id": 1,
                    "value": 2
                }
            ]
        },
        "msg/server/MsgSyncMapServer/MsgSyncMapServer": {
            "type": "Interface",
            "properties": [
                {
                    "id": 0,
                    "name": "playerId",
                    "type": {
                        "type": "String"
                    }
                },
                {
                    "id": 1,
                    "name": "state",
                    "type": {
                        "type": "Reference",
                        "target": "../../shared/game/state/OnlineState/OnlineState"
                    }
                },
                {
                    "id": 2,
                    "name": "data",
                    "type": {
                        "type": "Any"
                    }
                }
            ]
        },
        "PtlGetMsg/ReqGetMsg": {
            "type": "Interface",
            "extends": [
                {
                    "id": 0,
                    "type": {
                        "type": "Reference",
                        "target": "../../shared/base/BaseRequest"
                    }
                }
            ],
            "properties": [
                {
                    "id": 0,
                    "name": "playerId",
                    "type": {
                        "type": "String"
                    }
                },
                {
                    "id": 1,
                    "name": "roomId",
                    "type": {
                        "type": "String"
                    }
                }
            ]
        },
        "../../shared/base/BaseRequest": {
            "type": "Interface",
            "properties": [
                {
                    "id": 0,
                    "name": "__ssoToken",
                    "type": {
                        "type": "String"
                    },
                    "optional": true
                }
            ]
        },
        "PtlGetMsg/ResGetMsg": {
            "type": "Interface",
            "extends": [
                {
                    "id": 0,
                    "type": {
                        "type": "Reference",
                        "target": "../../shared/base/BaseResponse"
                    }
                }
            ],
            "properties": [
                {
                    "id": 0,
                    "name": "data",
                    "type": {
                        "type": "Any"
                    }
                },
                {
                    "id": 1,
                    "name": "players",
                    "type": {
                        "type": "Any"
                    }
                }
            ]
        },
        "../../shared/base/BaseResponse": {
            "type": "Interface",
            "properties": [
                {
                    "id": 0,
                    "name": "__ssoToken",
                    "type": {
                        "type": "String"
                    },
                    "optional": true
                }
            ]
        },
        "PtlRoomJoin/ReqRoomJoin": {
            "type": "Interface",
            "extends": [
                {
                    "id": 1,
                    "type": {
                        "type": "Reference",
                        "target": "../../shared/base/BaseRequest"
                    }
                }
            ],
            "properties": [
                {
                    "id": 0,
                    "name": "playerId",
                    "type": {
                        "type": "String"
                    }
                },
                {
                    "id": 1,
                    "name": "roomId",
                    "type": {
                        "type": "String"
                    }
                },
                {
                    "id": 2,
                    "name": "mapData",
                    "type": {
                        "type": "String"
                    },
                    "optional": true
                },
                {
                    "id": 3,
                    "name": "sn",
                    "type": {
                        "type": "Number"
                    },
                    "optional": true
                }
            ]
        },
        "PtlRoomJoin/ResRoomJoin": {
            "type": "Interface",
            "extends": [
                {
                    "id": 1,
                    "type": {
                        "type": "Reference",
                        "target": "../../shared/base/BaseResponse"
                    }
                }
            ],
            "properties": [
                {
                    "id": 0,
                    "name": "playerId",
                    "type": {
                        "type": "String"
                    }
                },
                {
                    "id": 3,
                    "name": "players",
                    "type": {
                        "type": "Array",
                        "elementType": {
                            "type": "Reference",
                            "target": "../../shared/game/state/PlayerState/PlayerState"
                        }
                    }
                },
                {
                    "id": 2,
                    "name": "mapData",
                    "type": {
                        "type": "String"
                    },
                    "optional": true
                },
                {
                    "id": 4,
                    "name": "sn",
                    "type": {
                        "type": "Number"
                    },
                    "optional": true
                },
                {
                    "id": 5,
                    "name": "startTime",
                    "type": {
                        "type": "Number"
                    },
                    "optional": true
                }
            ]
        },
        "PtlRoomLeave/ReqRoomLeave": {
            "type": "Interface",
            "extends": [
                {
                    "id": 1,
                    "type": {
                        "type": "Reference",
                        "target": "../../shared/base/BaseRequest"
                    }
                }
            ],
            "properties": [
                {
                    "id": 0,
                    "name": "playerId",
                    "type": {
                        "type": "String"
                    }
                },
                {
                    "id": 1,
                    "name": "roomId",
                    "type": {
                        "type": "String"
                    }
                }
            ]
        },
        "PtlRoomLeave/ResRoomLeave": {
            "type": "Interface",
            "extends": [
                {
                    "id": 1,
                    "type": {
                        "type": "Reference",
                        "target": "../../shared/base/BaseResponse"
                    }
                }
            ],
            "properties": [
                {
                    "id": 0,
                    "name": "playerId",
                    "type": {
                        "type": "String"
                    }
                }
            ]
        },
        "PtlTestMatch/ReqTestMatch": {
            "type": "Interface",
            "extends": [
                {
                    "id": 1,
                    "type": {
                        "type": "Reference",
                        "target": "../../shared/base/BaseRequest"
                    }
                }
            ],
            "properties": [
                {
                    "id": 0,
                    "name": "playerId",
                    "type": {
                        "type": "String"
                    }
                },
                {
                    "id": 1,
                    "name": "roomType",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 2,
                    "name": "cardId",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 3,
                    "name": "cup",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 4,
                    "name": "roomId",
                    "type": {
                        "type": "String"
                    }
                },
                {
                    "id": 5,
                    "name": "nickName",
                    "type": {
                        "type": "String"
                    }
                },
                {
                    "id": 6,
                    "name": "avatar",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 7,
                    "name": "version",
                    "type": {
                        "type": "Number"
                    }
                }
            ]
        },
        "PtlTestMatch/ResTestMatch": {
            "type": "Interface",
            "extends": [
                {
                    "id": 1,
                    "type": {
                        "type": "Reference",
                        "target": "../../shared/base/BaseResponse"
                    }
                }
            ],
            "properties": [
                {
                    "id": 0,
                    "name": "roomState",
                    "type": {
                        "type": "Reference",
                        "target": "../../shared/game/state/RoomState/RoomState"
                    }
                },
                {
                    "id": 1,
                    "name": "isRobot",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 2,
                    "name": "version",
                    "type": {
                        "type": "Number"
                    }
                }
            ]
        },
        "../../shared/game/state/RoomState/RoomState": {
            "type": "Interface",
            "properties": [
                {
                    "id": 0,
                    "name": "id",
                    "type": {
                        "type": "String"
                    }
                },
                {
                    "id": 1,
                    "name": "roomType",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 2,
                    "name": "server",
                    "type": {
                        "type": "String"
                    }
                },
                {
                    "id": 3,
                    "name": "players",
                    "type": {
                        "type": "Array",
                        "elementType": {
                            "type": "Reference",
                            "target": "../../shared/game/state/PlayerState/PlayerState"
                        }
                    }
                },
                {
                    "id": 4,
                    "name": "sn",
                    "type": {
                        "type": "Number"
                    }
                },
                {
                    "id": 8,
                    "name": "sendTag",
                    "type": {
                        "type": "Any"
                    }
                },
                {
                    "id": 7,
                    "name": "startTime",
                    "type": {
                        "type": "Number"
                    },
                    "optional": true
                },
                {
                    "id": 5,
                    "name": "conns",
                    "type": {
                        "type": "Array",
                        "elementType": {
                            "type": "Any"
                        }
                    },
                    "optional": true
                },
                {
                    "id": 9,
                    "name": "mapData",
                    "type": {
                        "type": "Any"
                    },
                    "optional": true
                }
            ]
        }
    }
};